@@ -3,9 +3,9 @@ import time
 
 import aria2p
 
-import OS
-import General
-import Logger as Log
+from . import OS
+from . import General
+from . import Logger as Log
 
 
 class Aria2:
@@ -13,7 +13,7 @@ class Aria2:
         # %% create server
         a2c_bin = General.gen_os_exe_name('aria2c')
         if OS.is_windows():
-            a2c_bin = f'bin/{a2c_bin}'
+            a2c_bin = f'{General.file_path(__file__)}/bin/{a2c_bin}'
         self.server = sp.Popen(
             [a2c_bin, '--enable-rpc', f'--rpc-listen-port={port}',
              f'--rpc-secret={secret}'],
